@@ -41,8 +41,9 @@ SEXP Runuran_cont_init (SEXP sexp_obj, SEXP sexp_env,
 /*---------------------------------------------------------------------------*/
 
 SEXP Runuran_cmv_init (SEXP sexp_obj, SEXP sexp_env, 
-		       SEXP sexp_dim, SEXP sexp_pdf, SEXP sexp_mode, 
-		       SEXP sexp_domain);
+		       SEXP sexp_dim, SEXP sexp_pdf, 
+		       SEXP sexp_mode, SEXP sexp_center, 
+		       SEXP sexp_ll, SEXP sexp_ur);
 /*---------------------------------------------------------------------------*/
 /* Create and initialize UNU.RAN object for cont. multivariate distribution. */
 /*---------------------------------------------------------------------------*/
