@@ -29,6 +29,7 @@
 #define _unur_cont_logPDF(x,distr)  ((*((distr)->data.cont.logpdf)) ((x),(distr)))
 #define _unur_cont_dlogPDF(x,distr) ((*((distr)->data.cont.dlogpdf))((x),(distr)))
 #define _unur_cont_CDF(x,distr)     ((*((distr)->data.cont.cdf)) ((x),(distr)))
+#define _unur_cont_logCDF(x,distr)  ((*((distr)->data.cont.logcdf)) ((x),(distr)))
 #define _unur_cont_HR(x,distr)      ((*((distr)->data.cont.hr))  ((x),(distr)))
 #define _unur_discr_PMF(x,distr)    ((*((distr)->data.discr.pmf))((x),(distr)))
 #define _unur_discr_CDF(x,distr)    ((*((distr)->data.discr.cdf))((x),(distr)))
@@ -42,6 +43,7 @@ double _unur_cvec_pdlogPDF(const double *x, int coord, struct unur_distr *distr)
 #define _unur_cont_have_dlogPDF(distr) (((distr)->data.cont.dlogpdf==NULL)?FALSE:TRUE)
 double _unur_distr_cont_eval_pdf_from_logpdf( double x, const struct unur_distr *distr );
 double _unur_distr_cont_eval_dpdf_from_dlogpdf( double x, const struct unur_distr *distr );
+double _unur_distr_cont_eval_cdf_from_logcdf( double x, const struct unur_distr *distr );
 double _unur_distr_cvec_eval_pdf_from_logpdf( const double *x, struct unur_distr *distr );
 int _unur_distr_cvec_eval_dpdf_from_dlogpdf( double *result, const double *x, struct unur_distr *distr );
 double _unur_distr_cvec_eval_pdpdf_from_pdlogpdf( const double *x, int coord, struct unur_distr *distr );
