@@ -491,6 +491,14 @@ int unur_empk_chg_varcor( UNUR_GEN *generator, int varcor );
 int unur_empk_set_positive( UNUR_PAR *parameters, int positive );
 UNUR_PAR *unur_empl_new( const UNUR_DISTR *distribution );
 UNUR_PAR *unur_hist_new( const UNUR_DISTR *distribution );
+UNUR_PAR *unur_mvtdr_new( const UNUR_DISTR *distribution );
+int unur_mvtdr_set_stepsmin( UNUR_PAR *parameters, int stepsmin );
+int unur_mvtdr_set_boundsplitting( UNUR_PAR *parameters, double boundsplitting );
+int unur_mvtdr_set_maxcones( UNUR_PAR *parameters, int maxcones );
+int unur_mvtdr_get_ncones( const UNUR_GEN *generator );
+double unur_mvtdr_get_hatvol( const UNUR_GEN *generator );
+int unur_mvtdr_set_verify( UNUR_PAR *parameters, int verify );
+int unur_mvtdr_chg_verify( UNUR_GEN *generator, int verify );
 UNUR_PAR *unur_norta_new( const UNUR_DISTR *distribution );
 UNUR_PAR *unur_vempk_new( const UNUR_DISTR *distribution );
 int unur_vempk_set_smoothing( UNUR_PAR *parameters, double smoothing );
